import { Injectable, ɵɵdefineInjectable, Component, Input, NgModule } from '@angular/core';
import { BehaviorSubject } from 'rxjs/internal/BehaviorSubject';
import { Subject, Observable } from 'rxjs';
import { NavigationEnd, Router, ActivatedRoute, RouterModule } from '@angular/router';
import { Subscription } from 'rxjs/internal/Subscription';
import { filter } from 'rxjs/operators';
import { isNullOrUndefined } from 'util';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NeoCrumbService {
    constructor() {
        this.change$ = new BehaviorSubject([]);
        this.postProcess$ = new Subject();
    }
    /**
     * @param {?} data
     * @return {?}
     */
    postProcess(data) {
        this.postProcess$.next(data);
    }
    /**
     * @param {?} data
     * @return {?}
     */
    change(data) {
        this.change$.next(data);
    }
    /**
     * @return {?}
     */
    get onPostProcess() {
        return new Observable((/**
         * @param {?} fn
         * @return {?}
         */
        fn => this.postProcess$.subscribe(fn)));
    }
    /**
     * @return {?}
     */
    get onChange() {
        return new Observable((/**
         * @param {?} fn
         * @return {?}
         */
        fn => this.change$.subscribe(fn)));
    }
}
NeoCrumbService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
NeoCrumbService.ctorParameters = () => [];
/** @nocollapse */ NeoCrumbService.ngInjectableDef = ɵɵdefineInjectable({ factory: function NeoCrumbService_Factory() { return new NeoCrumbService(); }, token: NeoCrumbService, providedIn: "root" });
if (false) {
    /**
     * @type {?}
     * @private
     */
    NeoCrumbService.prototype.change$;
    /**
     * @type {?}
     * @private
     */
    NeoCrumbService.prototype.postProcess$;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NeoCrumbComponent {
    /**
     * @param {?} router
     * @param {?} activatedRoute
     * @param {?} neoCrumbService
     */
    constructor(router, activatedRoute, neoCrumbService) {
        this.router = router;
        this.activatedRoute = activatedRoute;
        this.neoCrumbService = neoCrumbService;
        this.routeLinks = [];
        this.subscriptions = new Subscription();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.routeLinks = this.createBreadcrumbs(this.activatedRoute.root);
        /** @type {?} */
        const postProcessSubscription = this.neoCrumbService.onPostProcess
            .subscribe((/**
         * @param {?} value
         * @return {?}
         */
        value => this.routeLinks = value));
        /** @type {?} */
        const routerEventsSubscription = this.router.events
            .pipe(filter((/**
         * @param {?} event
         * @return {?}
         */
        event => event instanceof NavigationEnd)))
            .subscribe((/**
         * @return {?}
         */
        () => this.routeLinks = this.createBreadcrumbs(this.activatedRoute.root)));
        this.subscriptions.add(routerEventsSubscription);
        this.subscriptions.add(postProcessSubscription);
    }
    /**
     * @private
     * @param {?} route
     * @param {?=} url
     * @param {?=} breadcrumbs
     * @return {?}
     */
    createBreadcrumbs(route, url = '', breadcrumbs = []) {
        /** @type {?} */
        const children = route.children;
        if (children.length === 0) {
            this.neoCrumbService.change(breadcrumbs);
            return breadcrumbs;
        }
        for (const child of children) {
            /** @type {?} */
            const routeURL = this.getRouteUrl(child.snapshot.url);
            /** @type {?} */
            const breadcrumb = child.snapshot.data['breadcrumb'];
            if (routeURL !== '') {
                url += `/${routeURL}`;
            }
            if (!isNullOrUndefined(breadcrumb) && !(routeURL === '' && child.children.length < 1))
                breadcrumbs.push({ text: breadcrumb.text, link: url, iconClass: breadcrumb.iconClass, hide: breadcrumb.hide });
            return this.createBreadcrumbs(child, url, breadcrumbs);
        }
    }
    /**
     * @param {?} segment
     * @return {?}
     */
    getRouteUrl(segment) {
        return segment.map((/**
         * @param {?} seg
         * @return {?}
         */
        seg => seg.path)).join('/');
    }
    /**
     * @param {?} index
     * @return {?}
     */
    isActive(index) {
        return index == this.routeLinks.length - 1;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.subscriptions.unsubscribe();
    }
}
NeoCrumbComponent.decorators = [
    { type: Component, args: [{
                selector: 'nc-neo-crumb',
                template: "<nav aria-label=\"breadcrumb\" *ngIf=\"routeLinks && routeLinks.length && !routeLinks[routeLinks.length -1].hide\">\r\n\t<ol class=\"neo-breadcrumb\" [class.d-inline-block]=\"inlineBlock\">\r\n\t\t<ng-container *ngFor=\"let routeLink of routeLinks; let i = index\">\r\n\t\t\t<li class=\"neo-breadcrumb-item\" *ngIf=\"!isActive(i)\">\r\n\t\t\t\t<a [routerLink]=\"[routeLink.link]\">\r\n\t\t\t\t\t<i *ngIf=\"routeLink.iconClass\" [classList]=\"routeLink.iconClass\"></i>\r\n\t\t\t\t\t{{routeLink.text}}\r\n\t\t\t\t</a>\r\n\t\t\t</li>\r\n\t\t\t<li class=\"neo-breadcrumb-item active\" *ngIf=\"isActive(i)\">\r\n\t\t\t\t<i *ngIf=\"routeLink.iconClass\" [classList]=\"routeLink.iconClass\"></i>\r\n\t\t\t\t{{routeLink.text}}\r\n\t\t\t</li>\r\n\t\t</ng-container>\r\n\t</ol>\r\n</nav>\r\n"
            }] }
];
/** @nocollapse */
NeoCrumbComponent.ctorParameters = () => [
    { type: Router },
    { type: ActivatedRoute },
    { type: NeoCrumbService }
];
NeoCrumbComponent.propDecorators = {
    inlineBlock: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    NeoCrumbComponent.prototype.inlineBlock;
    /** @type {?} */
    NeoCrumbComponent.prototype.routeLinks;
    /** @type {?} */
    NeoCrumbComponent.prototype.subscriptions;
    /**
     * @type {?}
     * @private
     */
    NeoCrumbComponent.prototype.router;
    /**
     * @type {?}
     * @private
     */
    NeoCrumbComponent.prototype.activatedRoute;
    /**
     * @type {?}
     * @private
     */
    NeoCrumbComponent.prototype.neoCrumbService;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function RouteLink() { }
if (false) {
    /** @type {?} */
    RouteLink.prototype.text;
    /** @type {?} */
    RouteLink.prototype.link;
    /** @type {?|undefined} */
    RouteLink.prototype.iconClass;
    /** @type {?|undefined} */
    RouteLink.prototype.hide;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NeoCrumbModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: NeoCrumbModule,
        };
    }
    /**
     * @return {?}
     */
    static forChild() {
        return {
            ngModule: NeoCrumbModule
        };
    }
}
NeoCrumbModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NeoCrumbComponent],
                imports: [
                    CommonModule,
                    RouterModule.forChild([]),
                ],
                exports: [NeoCrumbComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NeoCrumbComponent, NeoCrumbModule, NeoCrumbService };
//# sourceMappingURL=ngx-neocrumb.js.map
